@@ -1,10 +1,13 @@
+import os
 from datetime import datetime, timedelta
 
 from airflow import DAG
 from airflow.sensors.time_sensor import TimeSensorAsync
 
+EXECUTION_TIMEOUT = int(os.getenv("EXECUTION_TIMEOUT", 6))
+
 default_args = {
-    "execution_timeout": timedelta(minutes=30),
+    "execution_timeout": timedelta(hours=EXECUTION_TIMEOUT),
 }
 
 with DAG(
@@ -20,4 +23,4 @@ with DAG(
         task_id="wait_for_me",
         target_time=(datetime.utcnow() + timedelta(seconds=3)).time(),
     )
-    # [START howto_operator_time_sensor_async]
+    # [END howto_operator_time_sensor_async]
